/*******************************************************************************
 * Copyright (c) 2000, 2008 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * Port to the D programming language:
 *     Frank Benoit <benoit@tionex.de>
 *******************************************************************************/
module dwtx.jface.text.DefaultLineTracker;

import dwt.dwthelper.utils;


/**
 * Standard implementation of {@link dwtx.jface.text.ILineTracker}.
 * <p>
 * The line tracker considers the three common line delimiters which are '\n',
 * '\r', '\r\n'.
 * <p>
 * This class is not intended to be subclassed.
 * </p>
 * @noextend This class is not intended to be subclassed by clients.
 */
public class DefaultLineTracker : AbstractLineTracker {

    /** The predefined delimiters of this tracker */
    public final static String[] DELIMITERS= { "\r", "\n", "\r\n" }; //$NON-NLS-3$ //$NON-NLS-1$ //$NON-NLS-2$
    /** A predefined delimiter information which is always reused as return value */
    private DelimiterInfo fDelimiterInfo= new DelimiterInfo();


    /**
     * Creates a standard line tracker.
     */
    public DefaultLineTracker() {
    }

    /*
     * @see dwtx.jface.text.ILineTracker#getLegalLineDelimiters()
     */
    public String[] getLegalLineDelimiters() {
        return TextUtilities.copy(DELIMITERS);
    }

    /*
     * @see dwtx.jface.text.AbstractLineTracker#nextDelimiterInfo(java.lang.String, int)
     */
    protected DelimiterInfo nextDelimiterInfo(String text, int offset) {

        char ch;
        int length= text.length();
        for (int i= offset; i < length; i++) {

            ch= text.charAt(i);
            if (ch is '\r') {

                if (i + 1 < length) {
                    if (text.charAt(i + 1) is '\n') {
                        fDelimiterInfo.delimiter= DELIMITERS[2];
                        fDelimiterInfo.delimiterIndex= i;
                        fDelimiterInfo.delimiterLength= 2;
                        return fDelimiterInfo;
                    }
                }

                fDelimiterInfo.delimiter= DELIMITERS[0];
                fDelimiterInfo.delimiterIndex= i;
                fDelimiterInfo.delimiterLength= 1;
                return fDelimiterInfo;

            } else if (ch is '\n') {

                fDelimiterInfo.delimiter= DELIMITERS[1];
                fDelimiterInfo.delimiterIndex= i;
                fDelimiterInfo.delimiterLength= 1;
                return fDelimiterInfo;
            }
        }

        return null;
    }
}
