/*******************************************************************************
 * Copyright (c) 2000, 2006 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * Port to the D programming language:
 *     Frank Benoit <benoit@tionex.de>
 *******************************************************************************/
module dwtx.jface.text.DocumentClone;

import dwt.dwthelper.utils;

import dwtx.core.runtime.Assert;


/**
 * An {@link dwtx.jface.text.IDocument} that is a read-only clone of another document.
 *
 * @since 3.0
 */
class DocumentClone : AbstractDocument {

    private static class StringTextStore : ITextStore {

        private String fContent;

        /**
         * Creates a new string text store with the given content.
         *
         * @param content the content
         */
        public StringTextStore(String content) {
            Assert.isNotNull(content);
            fContent= content;
        }

        /*
         * @see dwtx.jface.text.ITextStore#get(int)
         */
        public char get(int offset) {
            return fContent.charAt(offset);
        }

        /*
         * @see dwtx.jface.text.ITextStore#get(int, int)
         */
        public String get(int offset, int length) {
            return fContent.substring(offset, offset + length);
        }

        /*
         * @see dwtx.jface.text.ITextStore#getLength()
         */
        public int getLength() {
            return fContent.length();
        }

        /*
         * @see dwtx.jface.text.ITextStore#replace(int, int, java.lang.String)
         */
        public void replace(int offset, int length, String text) {
        }

        /*
         * @see dwtx.jface.text.ITextStore#set(java.lang.String)
         */
        public void set(String text) {
        }

    }

    /**
     * Creates a new document clone with the given content.
     *
     * @param content the content
     * @param lineDelimiters the line delimiters
     */
    public DocumentClone(String content, String[] lineDelimiters) {
        super();
        setTextStore(new StringTextStore(content));
        ConfigurableLineTracker tracker= new ConfigurableLineTracker(lineDelimiters);
        setLineTracker(tracker);
        getTracker().set(content);
        completeInitialization();
    }
}
